@@ -90,8 +90,8 @@ fit.demand_n_at_dose_selector_factory <- function(selector_factory,
   parent_selector <- selector_factory$parent %>%
     fit(outcomes, ...)
   return(demand_n_at_dose_selector(parent_selector = parent_selector,
-                                    n = selector_factory$n,
-                                    dose = selector_factory$dose))
+                                   n = selector_factory$n,
+                                   dose = selector_factory$dose))
 }
 
 # Selector interface
@@ -103,34 +103,39 @@ continue.demand_n_at_dose_selector <- function(x, ...) {
   # This selector affects when a trial ends but not which dose is selected.
   # If the parent selects no dose, this selector changes nothing.
   parent_dose <- x$parent %>% recommended_dose()
-  if(is.na(parent_dose)) {
-    return(x$parent %>% continue())
-  } else {
-    n_at_dose <- x %>% n_at_dose()
-    if(x$dose == 'any') {
-      if(any(n_at_dose >= x$n)) {
-        return(x$parent %>% continue())
-      } else {
-        return(TRUE)
-      }
-    }
-    else if(x$dose == 'recommended') {
-      rec_dose <- x %>% recommended_dose()
-      if(n_at_dose[rec_dose] >= x$n) {
-        return(x$parent %>% continue())
-      } else {
-        return(TRUE)
-      }
-    }
-    else if(x$dose >= 1 & x$dose <= x %>% num_doses()) {
-      if(n_at_dose[x$dose] >= x$n) {
-        return(x$parent %>% continue())
-      } else {
-        return(TRUE)
-      }
-    }
-
-    # By default:
+  if(any(is.na(parent_dose))) {
     return(x$parent %>% continue())
   }
+
+  if(is.character(x$dose)) {
+    # There are certain textual values of dose with accepted meanings.
+    # Parse those:
+    if(x$dose == "any") {
+      n_at_d <- x %>% n_at_dose()
+      if(any(n_at_d >= x$n)) {
+        return(x$parent %>% continue())
+      } else {
+        return(TRUE)
+      }
+    }
+    else if(x$dose == "recommended") {
+      rec_dose <- x %>% recommended_dose()
+      n_at_rec_d <- n_at_dose(x, dose = rec_dose)
+      if(n_at_rec_d >= x$n) {
+        return(x$parent %>% continue())
+      } else {
+        return(TRUE)
+      }
+    }
+  } else {
+    n_at_d <- n_at_dose(x$parent, dose = x$dose)
+    if(n_at_d >= x$n) {
+      return(x$parent %>% continue())
+    } else {
+      return(TRUE)
+    }
+  }
+
+  # By default:
+  return(x$parent %>% continue())
 }
