@@ -1,32 +1,41 @@
 
 #' Select dose by TPI's MTD-choosing algorithm.
 #'
-#' This method selects dose by the algorithm for identifying the maximum
-#' tolerable dose (MTD) described in Ji et al. (2007). This class is intended
-#' to be used when a TPI trial has reached its maximum sample size. Thus, it
-#' intends to make the final dose recommendation after the regular TPI dose
-#' selection algorithm, as implemented by \code{\link{get_tpi}}, including any
-#' additional behaviours that govern stopping (etc), has gracefully concluded a
-#' dose-finding trial. However, the class can be used in any scenario where
-#' there is a target toxicity rate. See Examples. Note - this class will not
-#' override the parent dose selector when the parent is advocating no dose. Thus
-#' this class will not reinstate a dangerous dose.
+#' Note: if you use this selector, it almost certainly needs to be the last
+#' example in the chain - see Example below. This method selects dose by the
+#' algorithm for identifying the maximum tolerable dose (MTD) described in Ji et
+#' al. (2007). This class is intended to be used when a TPI trial has reached
+#' its maximum sample size. Thus, it intends to make the final dose
+#' recommendation after the regular TPI dose selection algorithm, as implemented
+#' by \code{\link{get_tpi}}, including any additional behaviours that govern
+#' stopping (etc), has gracefully concluded a dose-finding trial. However, the
+#' class can be used in any scenario where there is a target toxicity rate. See
+#' Examples. Note - this class will not override the parent dose selector when
+#' the parent is advocating no dose. Thus this class will not reinstate a
+#' dangerous dose.
 #'
 #' @param parent_selector_factory Object of type \code{\link{selector_factory}}.
 #' @param when Either of: 'finally' to select dose only when the parent
-#' dose-selector has finished, by returning continue() == FALSE; or 'always'
-#' to use this dose-selection algorithm for every dose decision. As per the
-#' authors' original intentions, the default is 'finally'.
+#'   dose-selector has finished, by returning continue() == FALSE; or 'always'
+#'   to use this dose-selection algorithm for every dose decision. As per the
+#'   authors' original intentions, the default is 'finally'.
 #' @param target We seek a dose with this probability of toxicity. If not
-#' provided, the value will be sought from the parent dose-selector.
+#'   provided, the value will be sought from the parent dose-selector.
 #' @param exclusion_certainty Numeric, threshold posterior certainty required to
-#' exclude a dose for being excessively toxic. The authors discuss values in the
-#' range 0.7 - 0.95. Set to a value > 1 to suppress the dose exclusion
-#' mechanism. The authors use the Greek letter xi for this parameter.
+#'   exclude a dose for being excessively toxic. The authors discuss values in
+#'   the range 0.7 - 0.95. Set to a value > 1 to suppress the dose exclusion
+#'   mechanism. The authors use the Greek letter xi for this parameter.
 #' @param alpha First shape parameter of the beta prior distribution on the
-#' probability of toxicity.
+#'   probability of toxicity.
 #' @param beta Second shape parameter of the beta prior distribution on the
-#' probability of toxicity.
+#'   probability of toxicity.
+#' @param pava_just_tested_doses the design uses the PAVA method to estimate
+#'   monotonic Prob(Tox) at the doses. By default, this estimates Prob(Tox) for
+#'   doses that have not been tested in the trial and can lead to untested
+#'   doses being recommended. Set this option to TRUE to use PAVA only on tested
+#'   doses, leaving untested doses as NA and not-recommendable. Set to FALSE to
+#'   use PAVA at all doses and potentially recommend an untested dose. Default
+#'   is FALSE.
 #' @param ... Extra args are passed onwards.
 #'
 #' @return an object of type \code{\link{selector_factory}}.
@@ -61,16 +70,15 @@
 #' model3 %>% fit('1NNT') %>% recommended_dose()
 #' model3 %>% fit('1NNN 2NNT') %>% recommended_dose()
 #'
-#' @references
-#' Ji, Y., Li, Y., & Bekele, B. N. (2007).
-#' Dose-finding in phase I clinical trials based on toxicity probability
-#' intervals.
-#' Clinical Trials, 4(3), 235–244. https://doi.org/10.1177/1740774507079442
+#' @references Ji, Y., Li, Y., & Bekele, B. N. (2007). Dose-finding in phase I
+#' clinical trials based on toxicity probability intervals. Clinical Trials,
+#' 4(3), 235–244. https://doi.org/10.1177/1740774507079442
 select_tpi_mtd <- function(parent_selector_factory,
                            when = c('finally', 'always'),
                            target = NULL,
                            exclusion_certainty,
                            alpha = 1, beta = 1,
+                           pava_just_tested_doses = FALSE,
                            ...) {
 
   when <- match.arg(when)
@@ -82,6 +90,7 @@ select_tpi_mtd <- function(parent_selector_factory,
     exclusion_certainty = exclusion_certainty,
     alpha = alpha,
     beta = beta,
+    pava_just_tested_doses = pava_just_tested_doses,
     extra_args = list(...)
   )
   class(x) <- c('tpi_mtd_dose_selector_factory',
@@ -95,6 +104,7 @@ tpi_mtd_dose_selector <- function(parent_selector,
                                   target = NULL,
                                   exclusion_certainty,
                                   alpha, beta,
+                                  pava_just_tested_doses,
                                   ...) {
 
   when <- match.arg(when)
@@ -113,7 +123,8 @@ tpi_mtd_dose_selector <- function(parent_selector,
     target = target,
     exclusion_certainty = exclusion_certainty,
     alpha = alpha,
-    beta = beta
+    beta = beta,
+    pava_just_tested_doses = pava_just_tested_doses
   )
 
   class(l) = c('tpi_mtd_dose_selector',
@@ -137,7 +148,8 @@ fit.tpi_mtd_dose_selector_factory <- function(selector_factory, outcomes,
     target = selector_factory$target,
     exclusion_certainty = selector_factory$exclusion_certainty,
     alpha = selector_factory$alpha,
-    beta = selector_factory$beta
+    beta = selector_factory$beta,
+    pava_just_tested_doses = selector_factory$pava_just_tested_doses
   )
   do.call(tpi_mtd_dose_selector, args = args)
 }
@@ -150,13 +162,28 @@ mean_prob_tox.tpi_mtd_dose_selector <- function(x, ...) {
   post_mean = (x$alpha + tox_at_dose(x)) / (x$alpha + x$beta + n_at_dose(x))
   post_var = (x$alpha + tox_at_dose(x)) *
     (x$beta + n_at_dose(x) - tox_at_dose(x)) /
-    ((x$alpha + x$beta + n_at_dose(x))^2 * (x$alpha + x$beta + n_at_dose(x) + 1))
-  post_mean = pava(post_mean, wt = 1 / post_var)
-  return(post_mean)
+    ((x$alpha + x$beta + n_at_dose(x))^2 *
+       (x$alpha + x$beta + n_at_dose(x) + 1))
+  tested <- n_at_dose(x) > 0
+  if(x$pava_just_tested_doses & sum(tested) > 0) {
+    # Apply PAVA only to tested doses
+    tested_post_mean <- post_mean[tested]
+    tested_post_var <- post_var[tested]
+    tested_post_mean <- pava(tested_post_mean, wt = 1 / tested_post_var)
+    to_return <- post_mean # Mimic shape
+    to_return[!tested] <- NA
+    to_return[tested] <- tested_post_mean
+    return(to_return)
+  } else {
+    # Apply PAVA to all doses
+    post_mean = pava(post_mean, wt = 1 / post_var)
+    return(post_mean)
+  }
 }
 
 #' @export
 prob_tox_exceeds.tpi_mtd_dose_selector <- function(x, threshold, ...) {
+  # This routine uses only tested doses. Untested doses get NA.
   pava_bb_prob_tox_exceeds(x, threshold, alpha = x$alpha, beta = x$beta)
 }
 
@@ -248,4 +275,3 @@ as_tibble.tpi_mtd_dose_selector <- function(x, ...) {
 summary.tpi_mtd_dose_selector <- function(object, ...) {
   .dose_selector_summary(object, ...)
 }
-
