@@ -1112,6 +1112,9 @@ test_that('boin12_selector supports correct interface.', {
   expect_true(is.integer(tox(x)))
   expect_equal(length(tox(x)), num_patients(x))
 
+  expect_true(is.numeric(weight(x)))
+  expect_equal(length(weight(x)), num_patients(x))
+
   expect_equal(num_tox(x), 2)
   expect_true(is.integer(num_tox(x)))
 
@@ -1250,6 +1253,9 @@ test_that('boin12_selector supports correct interface.', {
   expect_true(is.integer(tox(x)))
   expect_equal(length(tox(x)), num_patients(x))
 
+  expect_true(is.numeric(weight(x)))
+  expect_equal(length(weight(x)), num_patients(x))
+
   expect_equal(num_tox(x), 0)
   expect_true(is.integer(num_tox(x)))
 
@@ -1391,6 +1397,9 @@ test_that('boin12_selector supports correct interface.', {
   expect_true(is.integer(tox(x)))
   expect_equal(length(tox(x)), num_patients(x))
 
+  expect_true(is.numeric(weight(x)))
+  expect_equal(length(weight(x)), num_patients(x))
+
   expect_equal(num_tox(x), 2)
   expect_true(is.integer(num_tox(x)))
 
