@@ -78,7 +78,8 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(all(model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,0,0)) == 0))
+                                               tox = c(0,0,0,0,0,0),
+                                              weight = c(1,1,1,1,1,1)) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 4)
@@ -173,7 +174,7 @@ test_that('follow_path_selector supports correct interface.', {
 
   mf <- model_frame(x)
   expect_equal(nrow(mf), 0)
-  expect_equal(ncol(mf), 4)
+  expect_equal(ncol(mf), 5)
 
   expect_equal(num_doses(x), 4)
   expect_true(is.integer(num_doses(x)))
@@ -272,7 +273,8 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,0,1))) == 0))
+                                               tox = c(0,0,0,0,0,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 4)
@@ -300,10 +302,9 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.integer(n_at_dose(x, dose = 1)))
   expect_equal(length(n_at_dose(x, dose = 1)), 1)
 
-  expect_equal(n_at_dose(x, dose = 'recommended'), NA)
+  expect_true(is.na(n_at_dose(x, dose = 'recommended')))
   expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
 
-  expect_equal(n_at_recommended_dose(x), NA)
   expect_true(is.na(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
@@ -366,7 +367,8 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(all(model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                               cohort = c(1,1,1,2,2,2),
                                               dose = c(1,1,1,2,2,2),
-                                              tox = c(0,0,0,0,0,1)) == 0))
+                                              tox = c(0,0,0,0,0,1),
+                                              weight = c(1,1,1,1,1,1)) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 2)
@@ -386,7 +388,6 @@ test_that('follow_path_selector supports correct interface.', {
   expect_true(is.integer(n_at_dose(x)))
   expect_equal(length(n_at_dose(x)), num_doses(x))
 
-  expect_equal(n_at_recommended_dose(x), NA)
   expect_true(is.na(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
