@@ -68,7 +68,8 @@ test_that('select_dose_by_cibp supports correct interface.', {
   expect_true(all(model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                               cohort = c(1,1,1,2,2,2),
                                               dose = c(1,1,1,2,2,2),
-                                              tox = c(0,0,0,0,0,0)) == 0))
+                                              tox = c(0,0,0,0,0,0),
+                                              weight = c(1,1,1,1,1,1)) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -178,7 +179,7 @@ test_that('select_dose_by_cibp supports correct interface.', {
 
   mf <- model_frame(x)
   expect_equal(nrow(mf), 0)
-  expect_equal(ncol(mf), 4)
+  expect_equal(ncol(mf), 5)
 
   expect_equal(num_doses(x), 5)
   expect_true(is.integer(num_doses(x)))
@@ -255,7 +256,6 @@ test_that('select_dose_by_cibp supports correct interface.', {
   expect_true(nrow(as_tibble(x)) >= num_doses(x))
 
 
-
   # Example 3, using tibble of outcomes
   set.seed(123)
   outcomes <- tibble(
@@ -292,7 +292,8 @@ test_that('select_dose_by_cibp supports correct interface.', {
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,0,1))) == 0))
+                                               tox = c(0,0,0,0,0,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -321,7 +322,7 @@ test_that('select_dose_by_cibp supports correct interface.', {
   expect_true(is.integer(n_at_dose(x, dose = 1)))
   expect_equal(length(n_at_dose(x, dose = 1)), 1)
 
-  expect_equal(n_at_dose(x, dose = 'recommended'), 0)
+  expect_equal(n_at_dose(x, dose = 'recommended'), 3)
   expect_true(is.integer(n_at_dose(x, dose = 'recommended')))
   expect_equal(length(n_at_dose(x, dose = 'recommended')), 1)
 
