@@ -113,7 +113,8 @@ test_that('select_mtpi2_mtd when=finally supports correct interface.', {
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,1,1))) == 0))
+                                               tox = c(0,0,0,0,1,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -225,7 +226,7 @@ test_that('select_mtpi2_mtd when=finally supports correct interface.', {
 
   mf <- model_frame(x)
   expect_equal(nrow(mf), 0)
-  expect_equal(ncol(mf), 4)
+  expect_equal(ncol(mf), 5)
 
   expect_equal(num_doses(x), 5)
   expect_true(is.integer(num_doses(x)))
@@ -330,7 +331,8 @@ test_that('select_mtpi2_mtd when=finally supports correct interface.', {
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,1,1))) == 0))
+                                               tox = c(0,0,0,0,1,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -448,7 +450,8 @@ test_that('select_mtpi2_mtd when=finally with stopper supports correct interface
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,1,1))) == 0))
+                                               tox = c(0,0,0,0,1,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -560,7 +563,7 @@ test_that('select_mtpi2_mtd when=finally with stopper supports correct interface
 
   mf <- model_frame(x)
   expect_equal(nrow(mf), 0)
-  expect_equal(ncol(mf), 4)
+  expect_equal(ncol(mf), 5)
 
   expect_equal(num_doses(x), 5)
   expect_true(is.integer(num_doses(x)))
@@ -665,7 +668,8 @@ test_that('select_mtpi2_mtd when=finally with stopper supports correct interface
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,1,1))) == 0))
+                                               tox = c(0,0,0,0,1,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -782,7 +786,8 @@ test_that('select_mtpi2_mtd when=always supports correct interface.', {
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,1,1))) == 0))
+                                               tox = c(0,0,0,0,1,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -894,7 +899,7 @@ test_that('select_mtpi2_mtd when=always supports correct interface.', {
 
   mf <- model_frame(x)
   expect_equal(nrow(mf), 0)
-  expect_equal(ncol(mf), 4)
+  expect_equal(ncol(mf), 5)
 
   expect_equal(num_doses(x), 5)
   expect_true(is.integer(num_doses(x)))
@@ -999,7 +1004,8 @@ test_that('select_mtpi2_mtd when=always supports correct interface.', {
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,1,1))) == 0))
+                                               tox = c(0,0,0,0,1,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
