@@ -74,7 +74,8 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(all(model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                               cohort = c(1,1,1,2,2,2),
                                               dose = c(1,1,1,2,2,2),
-                                              tox = c(0,0,0,0,0,0)) == 0))
+                                              tox = c(0,0,0,0,0,0),
+                                              weight = c(1,1,1,1,1,1)) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
@@ -183,7 +184,7 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
 
   mf <- model_frame(x)
   expect_equal(nrow(mf), 0)
-  expect_equal(ncol(mf), 4)
+  expect_equal(ncol(mf), 5)
 
   expect_equal(num_doses(x), 5)
   expect_true(is.integer(num_doses(x)))
@@ -296,7 +297,8 @@ test_that('stop_when_too_toxic_selector supports correct interface.', {
   expect_true(all((model_frame(x) - data.frame(patient = c(1,2,3,4,5,6),
                                                cohort = c(1,1,1,2,2,2),
                                                dose = c(1,1,1,2,2,2),
-                                               tox = c(0,0,0,0,0,1))) == 0))
+                                               tox = c(0,0,0,0,0,1),
+                                               weight = c(1,1,1,1,1,1))) == 0))
   expect_equal(nrow(model_frame(x)), num_patients(x))
 
   expect_equal(num_doses(x), 5)
